Documentation
¶
Overview ¶
Package petname is a library for generating human-readable, random names for objects (e.g. hostnames, containers, blobs).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GeneratePetName ¶
Generate generates and returns a random pet name. It takes two parameters: the number of words in the name, and a separator token. If a single word is requested, simply a Name() is returned. If two words are requested, a Adjective() and a Name() are returned. If three or more words are requested, a variable number of Adverb() and a Adjective and a Name() is returned. The separator can be any charater, string, or the empty string.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.